@@ -6,7 +6,6 @@ module.exports = function(grunt) {
 		nodeunit : {
 			zones : [
 				"tests/zones/**/*.js",
-				"tests/countries/*.js"
 			],
 			countries: [
 				"tests/countries/*.js"
@@ -44,7 +43,8 @@ module.exports = function(grunt) {
 		},
 
 		clean: {
-			data: ['temp']
+			data: ['temp'],
+			tests: ['tests/zones'],
 		},
 
 		exec: {
