@@ -18,8 +18,10 @@ module.exports = function (grunt) {
 			return tz.packCountry(unpacked);
 		});
 
-		grunt.file.mkdir('data/packed');
 		grunt.file.write('data/packed/' + version + '.json', JSON.stringify(output, null, '\t'));
+		if (version === 'latest') {
+			grunt.file.copy('data/packed/latest.json', 'data/packed/' + unpacked.version + '.json');
+		}
 
 		grunt.log.ok('Packed data for ' + version);
 	});
