@@ -102,6 +102,7 @@ exports.countries = {
 		test.deepEqual(tz.zone('America/Cayman').countries(), ["KY"]);
 		test.deepEqual(tz.zone('America/Chicago').countries(), ["US"]);
 		test.deepEqual(tz.zone('America/Chihuahua').countries(), ["MX"]);
+		test.deepEqual(tz.zone('America/Ciudad_Juarez').countries(), ["MX"]);
 		test.deepEqual(tz.zone('America/Coral_Harbour').countries(), []);
 		test.deepEqual(tz.zone('America/Cordoba').countries(), []);
 		test.deepEqual(tz.zone('America/Costa_Rica').countries(), ["CR"]);
@@ -176,7 +177,7 @@ exports.countries = {
 		test.deepEqual(tz.zone('America/Montserrat').countries(), ["MS"]);
 		test.deepEqual(tz.zone('America/Nassau').countries(), ["BS"]);
 		test.deepEqual(tz.zone('America/New_York').countries(), ["US"]);
-		test.deepEqual(tz.zone('America/Nipigon').countries(), ["CA"]);
+		test.deepEqual(tz.zone('America/Nipigon').countries(), []);
 		test.deepEqual(tz.zone('America/Nome').countries(), ["US"]);
 		test.deepEqual(tz.zone('America/Noronha').countries(), ["BR"]);
 		test.deepEqual(tz.zone('America/North_Dakota/Beulah').countries(), ["US"]);
@@ -184,7 +185,7 @@ exports.countries = {
 		test.deepEqual(tz.zone('America/North_Dakota/New_Salem').countries(), ["US"]);
 		test.deepEqual(tz.zone('America/Ojinaga').countries(), ["MX"]);
 		test.deepEqual(tz.zone('America/Panama').countries(), ["CA","KY","PA"]);
-		test.deepEqual(tz.zone('America/Pangnirtung').countries(), ["CA"]);
+		test.deepEqual(tz.zone('America/Pangnirtung').countries(), []);
 		test.deepEqual(tz.zone('America/Paramaribo').countries(), ["SR"]);
 		test.deepEqual(tz.zone('America/Phoenix').countries(), ["CA","US"]);
 		test.deepEqual(tz.zone('America/Port-au-Prince').countries(), ["HT"]);
@@ -193,7 +194,7 @@ exports.countries = {
 		test.deepEqual(tz.zone('America/Porto_Velho').countries(), ["BR"]);
 		test.deepEqual(tz.zone("America/Puerto_Rico").countries(), ["AG","AI","AW","BL","BQ","CA","CW","DM","GD","GP","KN","LC","MF","MS","PR","SX","TT","VC","VG","VI"]);
 		test.deepEqual(tz.zone('America/Punta_Arenas').countries(), ["CL"]);
-		test.deepEqual(tz.zone('America/Rainy_River').countries(), ["CA"]);
+		test.deepEqual(tz.zone('America/Rainy_River').countries(), []);
 		test.deepEqual(tz.zone('America/Rankin_Inlet').countries(), ["CA"]);
 		test.deepEqual(tz.zone('America/Recife').countries(), ["BR"]);
 		test.deepEqual(tz.zone('America/Regina').countries(), ["CA"]);
@@ -217,7 +218,7 @@ exports.countries = {
 		test.deepEqual(tz.zone('America/Swift_Current').countries(), ["CA"]);
 		test.deepEqual(tz.zone('America/Tegucigalpa').countries(), ["HN"]);
 		test.deepEqual(tz.zone('America/Thule').countries(), ["GL"]);
-		test.deepEqual(tz.zone('America/Thunder_Bay').countries(), ["CA"]);
+		test.deepEqual(tz.zone('America/Thunder_Bay').countries(), []);
 		test.deepEqual(tz.zone('America/Tijuana').countries(), ["MX"]);
 		test.deepEqual(tz.zone('America/Toronto').countries(), ["BS","CA"]);
 		test.deepEqual(tz.zone('America/Tortola').countries(), ["VG"]);
@@ -642,7 +643,7 @@ exports.countries = {
 		test.deepEqual(tz.zonesForCountry("BW"), ["Africa/Gaborone","Africa/Maputo"]);
 		test.deepEqual(tz.zonesForCountry("BY"), ["Europe/Minsk"]);
 		test.deepEqual(tz.zonesForCountry("BZ"), ["America/Belize"]);
-		test.deepEqual(tz.zonesForCountry("CA"), ["America/Atikokan","America/Blanc-Sablon","America/Cambridge_Bay","America/Creston","America/Dawson","America/Dawson_Creek","America/Edmonton","America/Fort_Nelson","America/Glace_Bay","America/Goose_Bay","America/Halifax","America/Inuvik","America/Iqaluit","America/Moncton","America/Nipigon","America/Panama","America/Pangnirtung","America/Phoenix","America/Puerto_Rico","America/Rainy_River","America/Rankin_Inlet","America/Regina","America/Resolute","America/St_Johns","America/Swift_Current","America/Thunder_Bay","America/Toronto","America/Vancouver","America/Whitehorse","America/Winnipeg","America/Yellowknife"]);
+		test.deepEqual(tz.zonesForCountry("CA"), ["America/Atikokan","America/Blanc-Sablon","America/Cambridge_Bay","America/Creston","America/Dawson","America/Dawson_Creek","America/Edmonton","America/Fort_Nelson","America/Glace_Bay","America/Goose_Bay","America/Halifax","America/Inuvik","America/Iqaluit","America/Moncton","America/Panama","America/Phoenix","America/Puerto_Rico","America/Rankin_Inlet","America/Regina","America/Resolute","America/St_Johns","America/Swift_Current","America/Toronto","America/Vancouver","America/Whitehorse","America/Winnipeg","America/Yellowknife"]);
 		test.deepEqual(tz.zonesForCountry("CC"), ["Asia/Yangon","Indian/Cocos"]);
 		test.deepEqual(tz.zonesForCountry("CD"), ["Africa/Kinshasa","Africa/Lagos","Africa/Lubumbashi","Africa/Maputo"]);
 		test.deepEqual(tz.zonesForCountry("CF"), ["Africa/Bangui","Africa/Lagos"]);
@@ -760,7 +761,7 @@ exports.countries = {
 		test.deepEqual(tz.zonesForCountry("MU"), ["Indian/Mauritius"]);
 		test.deepEqual(tz.zonesForCountry("MV"), ["Indian/Maldives"]);
 		test.deepEqual(tz.zonesForCountry("MW"), ["Africa/Blantyre","Africa/Maputo"]);
-		test.deepEqual(tz.zonesForCountry("MX"), ["America/Bahia_Banderas","America/Cancun","America/Chihuahua","America/Hermosillo","America/Matamoros","America/Mazatlan","America/Merida","America/Mexico_City","America/Monterrey","America/Ojinaga","America/Tijuana"]);
+		test.deepEqual(tz.zonesForCountry("MX"), ["America/Bahia_Banderas","America/Cancun","America/Chihuahua","America/Ciudad_Juarez","America/Hermosillo","America/Matamoros","America/Mazatlan","America/Merida","America/Mexico_City","America/Monterrey","America/Ojinaga","America/Tijuana"]);
 		test.deepEqual(tz.zonesForCountry("MY"), ["Asia/Kuala_Lumpur","Asia/Kuching","Asia/Singapore"]);
 		test.deepEqual(tz.zonesForCountry("MZ"), ["Africa/Maputo"]);
 		test.deepEqual(tz.zonesForCountry("NA"), ["Africa/Windhoek"]);
