@@ -9,7 +9,6 @@ exports["Africa/Asmara"] = {
 	"guess:by:abbr" : helpers.makeTestGuess("Africa/Asmara", { abbr: true, expect: "Africa/Nairobi" }),
 
 	"1908" : helpers.makeTestYear("Africa/Asmara", [
-		["1908-04-30T21:32:43+00:00", "23:59:59", "LMT", -8836 / 60],
 		["1908-04-30T21:32:44+00:00", "00:02:44", "+0230", -150]
 	]),
 
@@ -29,7 +28,6 @@ exports["Africa/Asmara"] = {
 	]),
 
 	"1942" : helpers.makeTestYear("Africa/Asmara", [
-		["1942-07-31T21:14:59+00:00", "23:59:59", "+0245", -165],
-		["1942-07-31T21:15:00+00:00", "00:15:00", "EAT", -180]
+		["1942-07-31T21:14:59+00:00", "23:59:59", "+0245", -165]
 	])
 };
\ No newline at end of file
