@@ -6,7 +6,7 @@ exports["Africa/Gaborone"] = {
 
 	"guess:by:offset" : helpers.makeTestGuess("Africa/Gaborone", { offset: true, expect: "Africa/Cairo" }),
 
-	"guess:by:abbr" : helpers.makeTestGuess("Africa/Gaborone", { abbr: true, expect: "Africa/Maputo" }),
+	"guess:by:abbr" : helpers.makeTestGuess("Africa/Gaborone", { abbr: true, expect: "Africa/Khartoum" }),
 
 
 };
\ No newline at end of file
