@@ -9,7 +9,6 @@ exports["Africa/Juba"] = {
 	"guess:by:abbr" : helpers.makeTestGuess("Africa/Juba", { abbr: true }),
 
 	"1930" : helpers.makeTestYear("Africa/Juba", [
-		["1930-12-31T21:53:31+00:00", "23:59:59", "LMT", -7588 / 60],
 		["1930-12-31T21:53:32+00:00", "23:53:32", "CAT", -120]
 	]),
 
@@ -131,7 +130,6 @@ exports["Africa/Juba"] = {
 	]),
 
 	"2021" : helpers.makeTestYear("Africa/Juba", [
-		["2021-01-31T20:59:59+00:00", "23:59:59", "EAT", -180],
-		["2021-01-31T21:00:00+00:00", "23:00:00", "CAT", -120]
+		["2021-01-31T20:59:59+00:00", "23:59:59", "EAT", -180]
 	])
 };
\ No newline at end of file
