@@ -9,7 +9,6 @@ exports["Africa/Khartoum"] = {
 	"guess:by:abbr" : helpers.makeTestGuess("Africa/Khartoum", { abbr: true }),
 
 	"1930" : helpers.makeTestYear("Africa/Khartoum", [
-		["1930-12-31T21:49:51+00:00", "23:59:59", "LMT", -7808 / 60],
 		["1930-12-31T21:49:52+00:00", "23:49:52", "CAT", -120]
 	]),
 
@@ -131,7 +130,6 @@ exports["Africa/Khartoum"] = {
 	]),
 
 	"2017" : helpers.makeTestYear("Africa/Khartoum", [
-		["2017-10-31T20:59:59+00:00", "23:59:59", "EAT", -180],
-		["2017-10-31T21:00:00+00:00", "23:00:00", "CAT", -120]
+		["2017-10-31T20:59:59+00:00", "23:59:59", "EAT", -180]
 	])
 };
\ No newline at end of file
