@@ -8,8 +8,5 @@ exports["Africa/Kigali"] = {
 
 	"guess:by:abbr" : helpers.makeTestGuess("Africa/Kigali", { abbr: true, expect: "Africa/Khartoum" }),
 
-	"1903" : helpers.makeTestYear("Africa/Kigali", [
-		["1903-02-28T21:49:39+00:00", "23:59:59", "LMT", -7820 / 60],
-		["1903-02-28T21:49:40+00:00", "23:49:40", "CAT", -120]
-	])
+
 };
\ No newline at end of file
