@@ -8,6 +8,10 @@ exports["Africa/Maseru"] = {
 
 	"guess:by:abbr" : helpers.makeTestGuess("Africa/Maseru", { abbr: true, expect: "Africa/Johannesburg" }),
 
+	"1892" : helpers.makeTestYear("Africa/Maseru", [
+		["1892-02-07T22:08:00+00:00", "23:38:00", "SAST", -90]
+	]),
+
 	"1903" : helpers.makeTestYear("Africa/Maseru", [
 		["1903-02-28T22:29:59+00:00", "23:59:59", "SAST", -90],
 		["1903-02-28T22:30:00+00:00", "00:30:00", "SAST", -120]
@@ -26,7 +30,6 @@ exports["Africa/Maseru"] = {
 	]),
 
 	"1944" : helpers.makeTestYear("Africa/Maseru", [
-		["1944-03-18T22:59:59+00:00", "01:59:59", "SAST", -180],
-		["1944-03-18T23:00:00+00:00", "01:00:00", "SAST", -120]
+		["1944-03-18T22:59:59+00:00", "01:59:59", "SAST", -180]
 	])
 };
\ No newline at end of file
