@@ -9,7 +9,6 @@ exports["Africa/Ndjamena"] = {
 	"guess:by:abbr" : helpers.makeTestGuess("Africa/Ndjamena", { abbr: true, expect: "Africa/Lagos" }),
 
 	"1911" : helpers.makeTestYear("Africa/Ndjamena", [
-		["1911-12-31T22:59:47+00:00", "23:59:59", "LMT", -3612 / 60],
 		["1911-12-31T22:59:48+00:00", "23:59:48", "WAT", -60]
 	]),
 
@@ -19,7 +18,6 @@ exports["Africa/Ndjamena"] = {
 	]),
 
 	"1980" : helpers.makeTestYear("Africa/Ndjamena", [
-		["1980-03-07T21:59:59+00:00", "23:59:59", "WAST", -120],
-		["1980-03-07T22:00:00+00:00", "23:00:00", "WAT", -60]
+		["1980-03-07T21:59:59+00:00", "23:59:59", "WAST", -120]
 	])
 };
\ No newline at end of file
