@@ -4,9 +4,13 @@ var helpers = require("../../../helpers/helpers");
 
 exports["America/Argentina/ComodRivadavia"] = {
 
-	"guess:by:offset" : helpers.makeTestGuess("America/Argentina/ComodRivadavia", { offset: true, expect: "America/Fortaleza" }),
+	"guess:by:offset" : helpers.makeTestGuess("America/Argentina/ComodRivadavia", { offset: true, expect: "America/Sao_Paulo" }),
 
-	"guess:by:abbr" : helpers.makeTestGuess("America/Argentina/ComodRivadavia", { abbr: true, expect: "America/Fortaleza" }),
+	"guess:by:abbr" : helpers.makeTestGuess("America/Argentina/ComodRivadavia", { abbr: true, expect: "America/Sao_Paulo" }),
+
+	"1894" : helpers.makeTestYear("America/Argentina/ComodRivadavia", [
+		["1894-10-31T04:23:08+00:00", "00:06:20", "CMT", 15408 / 60]
+	]),
 
 	"1920" : helpers.makeTestYear("America/Argentina/ComodRivadavia", [
 		["1920-05-01T04:16:47+00:00", "23:59:59", "CMT", 15408 / 60],
@@ -226,7 +230,6 @@ exports["America/Argentina/ComodRivadavia"] = {
 	]),
 
 	"2008" : helpers.makeTestYear("America/Argentina/ComodRivadavia", [
-		["2008-03-16T01:59:59+00:00", "23:59:59", "-02", 120],
-		["2008-03-16T02:00:00+00:00", "23:00:00", "-03", 180]
+		["2008-03-16T01:59:59+00:00", "23:59:59", "-02", 120]
 	])
 };
\ No newline at end of file
