@@ -4,9 +4,13 @@ var helpers = require("../../helpers/helpers");
 
 exports["America/Buenos_Aires"] = {
 
-	"guess:by:offset" : helpers.makeTestGuess("America/Buenos_Aires", { offset: true, expect: "America/Fortaleza" }),
+	"guess:by:offset" : helpers.makeTestGuess("America/Buenos_Aires", { offset: true, expect: "America/Sao_Paulo" }),
 
-	"guess:by:abbr" : helpers.makeTestGuess("America/Buenos_Aires", { abbr: true, expect: "America/Fortaleza" }),
+	"guess:by:abbr" : helpers.makeTestGuess("America/Buenos_Aires", { abbr: true, expect: "America/Sao_Paulo" }),
+
+	"1894" : helpers.makeTestYear("America/Buenos_Aires", [
+		["1894-10-31T03:53:48+00:00", "23:37:00", "CMT", 15408 / 60]
+	]),
 
 	"1920" : helpers.makeTestYear("America/Buenos_Aires", [
 		["1920-05-01T04:16:47+00:00", "23:59:59", "CMT", 15408 / 60],
@@ -226,7 +230,6 @@ exports["America/Buenos_Aires"] = {
 	]),
 
 	"2009" : helpers.makeTestYear("America/Buenos_Aires", [
-		["2009-03-15T01:59:59+00:00", "23:59:59", "-02", 120],
-		["2009-03-15T02:00:00+00:00", "23:00:00", "-03", 180]
+		["2009-03-15T01:59:59+00:00", "23:59:59", "-02", 120]
 	])
 };
\ No newline at end of file
