@@ -9,7 +9,6 @@ exports["America/Chihuahua"] = {
 	"guess:by:abbr" : helpers.makeTestGuess("America/Chihuahua", { abbr: true }),
 
 	"1922" : helpers.makeTestYear("America/Chihuahua", [
-		["1922-01-01T06:59:59+00:00", "23:55:39", "LMT", 25460 / 60],
 		["1922-01-01T07:00:00+00:00", "00:00:00", "MST", 420]
 	]),
 
@@ -25,8 +24,8 @@ exports["America/Chihuahua"] = {
 
 	"1931" : helpers.makeTestYear("America/Chihuahua", [
 		["1931-05-02T05:59:59+00:00", "22:59:59", "MST", 420],
-		["1931-05-02T06:00:00+00:00", "00:00:00", "CST", 360],
-		["1931-10-01T05:59:59+00:00", "23:59:59", "CST", 360],
+		["1931-05-02T06:00:00+00:00", "00:00:00", "MDT", 360],
+		["1931-10-01T05:59:59+00:00", "23:59:59", "MDT", 360],
 		["1931-10-01T06:00:00+00:00", "23:00:00", "MST", 420]
 	]),
 
@@ -220,112 +219,6 @@ exports["America/Chihuahua"] = {
 	"2022" : helpers.makeTestYear("America/Chihuahua", [
 		["2022-04-03T08:59:59+00:00", "01:59:59", "MST", 420],
 		["2022-04-03T09:00:00+00:00", "03:00:00", "MDT", 360],
-		["2022-10-30T07:59:59+00:00", "01:59:59", "MDT", 360],
-		["2022-10-30T08:00:00+00:00", "01:00:00", "MST", 420]
-	]),
-
-	"2023" : helpers.makeTestYear("America/Chihuahua", [
-		["2023-04-02T08:59:59+00:00", "01:59:59", "MST", 420],
-		["2023-04-02T09:00:00+00:00", "03:00:00", "MDT", 360],
-		["2023-10-29T07:59:59+00:00", "01:59:59", "MDT", 360],
-		["2023-10-29T08:00:00+00:00", "01:00:00", "MST", 420]
-	]),
-
-	"2024" : helpers.makeTestYear("America/Chihuahua", [
-		["2024-04-07T08:59:59+00:00", "01:59:59", "MST", 420],
-		["2024-04-07T09:00:00+00:00", "03:00:00", "MDT", 360],
-		["2024-10-27T07:59:59+00:00", "01:59:59", "MDT", 360],
-		["2024-10-27T08:00:00+00:00", "01:00:00", "MST", 420]
-	]),
-
-	"2025" : helpers.makeTestYear("America/Chihuahua", [
-		["2025-04-06T08:59:59+00:00", "01:59:59", "MST", 420],
-		["2025-04-06T09:00:00+00:00", "03:00:00", "MDT", 360],
-		["2025-10-26T07:59:59+00:00", "01:59:59", "MDT", 360],
-		["2025-10-26T08:00:00+00:00", "01:00:00", "MST", 420]
-	]),
-
-	"2026" : helpers.makeTestYear("America/Chihuahua", [
-		["2026-04-05T08:59:59+00:00", "01:59:59", "MST", 420],
-		["2026-04-05T09:00:00+00:00", "03:00:00", "MDT", 360],
-		["2026-10-25T07:59:59+00:00", "01:59:59", "MDT", 360],
-		["2026-10-25T08:00:00+00:00", "01:00:00", "MST", 420]
-	]),
-
-	"2027" : helpers.makeTestYear("America/Chihuahua", [
-		["2027-04-04T08:59:59+00:00", "01:59:59", "MST", 420],
-		["2027-04-04T09:00:00+00:00", "03:00:00", "MDT", 360],
-		["2027-10-31T07:59:59+00:00", "01:59:59", "MDT", 360],
-		["2027-10-31T08:00:00+00:00", "01:00:00", "MST", 420]
-	]),
-
-	"2028" : helpers.makeTestYear("America/Chihuahua", [
-		["2028-04-02T08:59:59+00:00", "01:59:59", "MST", 420],
-		["2028-04-02T09:00:00+00:00", "03:00:00", "MDT", 360],
-		["2028-10-29T07:59:59+00:00", "01:59:59", "MDT", 360],
-		["2028-10-29T08:00:00+00:00", "01:00:00", "MST", 420]
-	]),
-
-	"2029" : helpers.makeTestYear("America/Chihuahua", [
-		["2029-04-01T08:59:59+00:00", "01:59:59", "MST", 420],
-		["2029-04-01T09:00:00+00:00", "03:00:00", "MDT", 360],
-		["2029-10-28T07:59:59+00:00", "01:59:59", "MDT", 360],
-		["2029-10-28T08:00:00+00:00", "01:00:00", "MST", 420]
-	]),
-
-	"2030" : helpers.makeTestYear("America/Chihuahua", [
-		["2030-04-07T08:59:59+00:00", "01:59:59", "MST", 420],
-		["2030-04-07T09:00:00+00:00", "03:00:00", "MDT", 360],
-		["2030-10-27T07:59:59+00:00", "01:59:59", "MDT", 360],
-		["2030-10-27T08:00:00+00:00", "01:00:00", "MST", 420]
-	]),
-
-	"2031" : helpers.makeTestYear("America/Chihuahua", [
-		["2031-04-06T08:59:59+00:00", "01:59:59", "MST", 420],
-		["2031-04-06T09:00:00+00:00", "03:00:00", "MDT", 360],
-		["2031-10-26T07:59:59+00:00", "01:59:59", "MDT", 360],
-		["2031-10-26T08:00:00+00:00", "01:00:00", "MST", 420]
-	]),
-
-	"2032" : helpers.makeTestYear("America/Chihuahua", [
-		["2032-04-04T08:59:59+00:00", "01:59:59", "MST", 420],
-		["2032-04-04T09:00:00+00:00", "03:00:00", "MDT", 360],
-		["2032-10-31T07:59:59+00:00", "01:59:59", "MDT", 360],
-		["2032-10-31T08:00:00+00:00", "01:00:00", "MST", 420]
-	]),
-
-	"2033" : helpers.makeTestYear("America/Chihuahua", [
-		["2033-04-03T08:59:59+00:00", "01:59:59", "MST", 420],
-		["2033-04-03T09:00:00+00:00", "03:00:00", "MDT", 360],
-		["2033-10-30T07:59:59+00:00", "01:59:59", "MDT", 360],
-		["2033-10-30T08:00:00+00:00", "01:00:00", "MST", 420]
-	]),
-
-	"2034" : helpers.makeTestYear("America/Chihuahua", [
-		["2034-04-02T08:59:59+00:00", "01:59:59", "MST", 420],
-		["2034-04-02T09:00:00+00:00", "03:00:00", "MDT", 360],
-		["2034-10-29T07:59:59+00:00", "01:59:59", "MDT", 360],
-		["2034-10-29T08:00:00+00:00", "01:00:00", "MST", 420]
-	]),
-
-	"2035" : helpers.makeTestYear("America/Chihuahua", [
-		["2035-04-01T08:59:59+00:00", "01:59:59", "MST", 420],
-		["2035-04-01T09:00:00+00:00", "03:00:00", "MDT", 360],
-		["2035-10-28T07:59:59+00:00", "01:59:59", "MDT", 360],
-		["2035-10-28T08:00:00+00:00", "01:00:00", "MST", 420]
-	]),
-
-	"2036" : helpers.makeTestYear("America/Chihuahua", [
-		["2036-04-06T08:59:59+00:00", "01:59:59", "MST", 420],
-		["2036-04-06T09:00:00+00:00", "03:00:00", "MDT", 360],
-		["2036-10-26T07:59:59+00:00", "01:59:59", "MDT", 360],
-		["2036-10-26T08:00:00+00:00", "01:00:00", "MST", 420]
-	]),
-
-	"2037" : helpers.makeTestYear("America/Chihuahua", [
-		["2037-04-05T08:59:59+00:00", "01:59:59", "MST", 420],
-		["2037-04-05T09:00:00+00:00", "03:00:00", "MDT", 360],
-		["2037-10-25T07:59:59+00:00", "01:59:59", "MDT", 360],
-		["2037-10-25T08:00:00+00:00", "01:00:00", "MST", 420]
+		["2022-10-30T07:59:59+00:00", "01:59:59", "MDT", 360]
 	])
 };
\ No newline at end of file
