@@ -8,8 +8,11 @@ exports["America/Coral_Harbour"] = {
 
 	"guess:by:abbr" : helpers.makeTestGuess("America/Coral_Harbour", { abbr: true, expect: "America/Panama" }),
 
+	"1890" : helpers.makeTestYear("America/Coral_Harbour", [
+		["1890-01-01T05:18:08+00:00", "23:58:32", "CMT", 19176 / 60]
+	]),
+
 	"1908" : helpers.makeTestYear("America/Coral_Harbour", [
-		["1908-04-22T05:19:35+00:00", "23:59:59", "CMT", 19176 / 60],
-		["1908-04-22T05:19:36+00:00", "00:19:36", "EST", 300]
+		["1908-04-22T05:19:35+00:00", "23:59:59", "CMT", 19176 / 60]
 	])
 };
\ No newline at end of file
