@@ -4,12 +4,11 @@ var helpers = require("../../helpers/helpers");
 
 exports["America/Cuiaba"] = {
 
-	"guess:by:offset" : helpers.makeTestGuess("America/Cuiaba", { offset: true, expect: "America/Campo_Grande" }),
+	"guess:by:offset" : helpers.makeTestGuess("America/Cuiaba", { offset: true, expect: "America/Santo_Domingo" }),
 
-	"guess:by:abbr" : helpers.makeTestGuess("America/Cuiaba", { abbr: true, expect: "America/Campo_Grande" }),
+	"guess:by:abbr" : helpers.makeTestGuess("America/Cuiaba", { abbr: true, expect: "America/Santo_Domingo" }),
 
 	"1914" : helpers.makeTestYear("America/Cuiaba", [
-		["1914-01-01T03:44:19+00:00", "23:59:59", "LMT", 13460 / 60],
 		["1914-01-01T03:44:20+00:00", "23:44:20", "-04", 240]
 	]),
 
@@ -332,135 +331,6 @@ exports["America/Cuiaba"] = {
 	]),
 
 	"2019" : helpers.makeTestYear("America/Cuiaba", [
-		["2019-02-17T02:59:59+00:00", "23:59:59", "-03", 180],
-		["2019-02-17T03:00:00+00:00", "23:00:00", "-04", 240],
-		["2019-11-03T03:59:59+00:00", "23:59:59", "-04", 240],
-		["2019-11-03T04:00:00+00:00", "01:00:00", "-03", 180]
-	]),
-
-	"2020" : helpers.makeTestYear("America/Cuiaba", [
-		["2020-02-16T02:59:59+00:00", "23:59:59", "-03", 180],
-		["2020-02-16T03:00:00+00:00", "23:00:00", "-04", 240],
-		["2020-11-01T03:59:59+00:00", "23:59:59", "-04", 240],
-		["2020-11-01T04:00:00+00:00", "01:00:00", "-03", 180]
-	]),
-
-	"2021" : helpers.makeTestYear("America/Cuiaba", [
-		["2021-02-21T02:59:59+00:00", "23:59:59", "-03", 180],
-		["2021-02-21T03:00:00+00:00", "23:00:00", "-04", 240],
-		["2021-11-07T03:59:59+00:00", "23:59:59", "-04", 240],
-		["2021-11-07T04:00:00+00:00", "01:00:00", "-03", 180]
-	]),
-
-	"2022" : helpers.makeTestYear("America/Cuiaba", [
-		["2022-02-20T02:59:59+00:00", "23:59:59", "-03", 180],
-		["2022-02-20T03:00:00+00:00", "23:00:00", "-04", 240],
-		["2022-11-06T03:59:59+00:00", "23:59:59", "-04", 240],
-		["2022-11-06T04:00:00+00:00", "01:00:00", "-03", 180]
-	]),
-
-	"2023" : helpers.makeTestYear("America/Cuiaba", [
-		["2023-02-26T02:59:59+00:00", "23:59:59", "-03", 180],
-		["2023-02-26T03:00:00+00:00", "23:00:00", "-04", 240],
-		["2023-11-05T03:59:59+00:00", "23:59:59", "-04", 240],
-		["2023-11-05T04:00:00+00:00", "01:00:00", "-03", 180]
-	]),
-
-	"2024" : helpers.makeTestYear("America/Cuiaba", [
-		["2024-02-18T02:59:59+00:00", "23:59:59", "-03", 180],
-		["2024-02-18T03:00:00+00:00", "23:00:00", "-04", 240],
-		["2024-11-03T03:59:59+00:00", "23:59:59", "-04", 240],
-		["2024-11-03T04:00:00+00:00", "01:00:00", "-03", 180]
-	]),
-
-	"2025" : helpers.makeTestYear("America/Cuiaba", [
-		["2025-02-16T02:59:59+00:00", "23:59:59", "-03", 180],
-		["2025-02-16T03:00:00+00:00", "23:00:00", "-04", 240],
-		["2025-11-02T03:59:59+00:00", "23:59:59", "-04", 240],
-		["2025-11-02T04:00:00+00:00", "01:00:00", "-03", 180]
-	]),
-
-	"2026" : helpers.makeTestYear("America/Cuiaba", [
-		["2026-02-22T02:59:59+00:00", "23:59:59", "-03", 180],
-		["2026-02-22T03:00:00+00:00", "23:00:00", "-04", 240],
-		["2026-11-01T03:59:59+00:00", "23:59:59", "-04", 240],
-		["2026-11-01T04:00:00+00:00", "01:00:00", "-03", 180]
-	]),
-
-	"2027" : helpers.makeTestYear("America/Cuiaba", [
-		["2027-02-21T02:59:59+00:00", "23:59:59", "-03", 180],
-		["2027-02-21T03:00:00+00:00", "23:00:00", "-04", 240],
-		["2027-11-07T03:59:59+00:00", "23:59:59", "-04", 240],
-		["2027-11-07T04:00:00+00:00", "01:00:00", "-03", 180]
-	]),
-
-	"2028" : helpers.makeTestYear("America/Cuiaba", [
-		["2028-02-20T02:59:59+00:00", "23:59:59", "-03", 180],
-		["2028-02-20T03:00:00+00:00", "23:00:00", "-04", 240],
-		["2028-11-05T03:59:59+00:00", "23:59:59", "-04", 240],
-		["2028-11-05T04:00:00+00:00", "01:00:00", "-03", 180]
-	]),
-
-	"2029" : helpers.makeTestYear("America/Cuiaba", [
-		["2029-02-18T02:59:59+00:00", "23:59:59", "-03", 180],
-		["2029-02-18T03:00:00+00:00", "23:00:00", "-04", 240],
-		["2029-11-04T03:59:59+00:00", "23:59:59", "-04", 240],
-		["2029-11-04T04:00:00+00:00", "01:00:00", "-03", 180]
-	]),
-
-	"2030" : helpers.makeTestYear("America/Cuiaba", [
-		["2030-02-17T02:59:59+00:00", "23:59:59", "-03", 180],
-		["2030-02-17T03:00:00+00:00", "23:00:00", "-04", 240],
-		["2030-11-03T03:59:59+00:00", "23:59:59", "-04", 240],
-		["2030-11-03T04:00:00+00:00", "01:00:00", "-03", 180]
-	]),
-
-	"2031" : helpers.makeTestYear("America/Cuiaba", [
-		["2031-02-16T02:59:59+00:00", "23:59:59", "-03", 180],
-		["2031-02-16T03:00:00+00:00", "23:00:00", "-04", 240],
-		["2031-11-02T03:59:59+00:00", "23:59:59", "-04", 240],
-		["2031-11-02T04:00:00+00:00", "01:00:00", "-03", 180]
-	]),
-
-	"2032" : helpers.makeTestYear("America/Cuiaba", [
-		["2032-02-15T02:59:59+00:00", "23:59:59", "-03", 180],
-		["2032-02-15T03:00:00+00:00", "23:00:00", "-04", 240],
-		["2032-11-07T03:59:59+00:00", "23:59:59", "-04", 240],
-		["2032-11-07T04:00:00+00:00", "01:00:00", "-03", 180]
-	]),
-
-	"2033" : helpers.makeTestYear("America/Cuiaba", [
-		["2033-02-20T02:59:59+00:00", "23:59:59", "-03", 180],
-		["2033-02-20T03:00:00+00:00", "23:00:00", "-04", 240],
-		["2033-11-06T03:59:59+00:00", "23:59:59", "-04", 240],
-		["2033-11-06T04:00:00+00:00", "01:00:00", "-03", 180]
-	]),
-
-	"2034" : helpers.makeTestYear("America/Cuiaba", [
-		["2034-02-26T02:59:59+00:00", "23:59:59", "-03", 180],
-		["2034-02-26T03:00:00+00:00", "23:00:00", "-04", 240],
-		["2034-11-05T03:59:59+00:00", "23:59:59", "-04", 240],
-		["2034-11-05T04:00:00+00:00", "01:00:00", "-03", 180]
-	]),
-
-	"2035" : helpers.makeTestYear("America/Cuiaba", [
-		["2035-02-18T02:59:59+00:00", "23:59:59", "-03", 180],
-		["2035-02-18T03:00:00+00:00", "23:00:00", "-04", 240],
-		["2035-11-04T03:59:59+00:00", "23:59:59", "-04", 240],
-		["2035-11-04T04:00:00+00:00", "01:00:00", "-03", 180]
-	]),
-
-	"2036" : helpers.makeTestYear("America/Cuiaba", [
-		["2036-02-17T02:59:59+00:00", "23:59:59", "-03", 180],
-		["2036-02-17T03:00:00+00:00", "23:00:00", "-04", 240],
-		["2036-11-02T03:59:59+00:00", "23:59:59", "-04", 240],
-		["2036-11-02T04:00:00+00:00", "01:00:00", "-03", 180]
-	]),
-
-	"2037" : helpers.makeTestYear("America/Cuiaba", [
-		["2037-02-22T02:59:59+00:00", "23:59:59", "-03", 180],
-		["2037-02-22T03:00:00+00:00", "23:00:00", "-04", 240],
-		["2037-11-01T03:59:59+00:00", "23:59:59", "-04", 240],
-		["2037-11-01T04:00:00+00:00", "01:00:00", "-03", 180]
+		["2019-02-17T02:59:59+00:00", "23:59:59", "-03", 180]
 	])
 };
\ No newline at end of file
