@@ -8,6 +8,10 @@ exports["America/Fort_Nelson"] = {
 
 	"guess:by:abbr" : helpers.makeTestGuess("America/Fort_Nelson", { abbr: true, expect: "America/Phoenix" }),
 
+	"1884" : helpers.makeTestYear("America/Fort_Nelson", [
+		["1884-01-01T08:10:47+00:00", "00:10:47", "PST", 480]
+	]),
+
 	"1918" : helpers.makeTestYear("America/Fort_Nelson", [
 		["1918-04-14T09:59:59+00:00", "01:59:59", "PST", 480],
 		["1918-04-14T10:00:00+00:00", "03:00:00", "PDT", 420],
@@ -504,7 +508,6 @@ exports["America/Fort_Nelson"] = {
 	]),
 
 	"2015" : helpers.makeTestYear("America/Fort_Nelson", [
-		["2015-03-08T09:59:59+00:00", "01:59:59", "PST", 480],
-		["2015-03-08T10:00:00+00:00", "03:00:00", "MST", 420]
+		["2015-03-08T09:59:59+00:00", "01:59:59", "PST", 480]
 	])
 };
\ No newline at end of file
