@@ -9,7 +9,6 @@ exports["America/Godthab"] = {
 	"guess:by:abbr" : helpers.makeTestGuess("America/Godthab", { abbr: true }),
 
 	"1916" : helpers.makeTestYear("America/Godthab", [
-		["1916-07-28T03:26:55+00:00", "23:59:59", "LMT", 12416 / 60],
 		["1916-07-28T03:26:56+00:00", "00:26:56", "-03", 180]
 	]),
 
@@ -315,107 +314,6 @@ exports["America/Godthab"] = {
 	]),
 
 	"2023" : helpers.makeTestYear("America/Godthab", [
-		["2023-03-26T00:59:59+00:00", "21:59:59", "-03", 180],
-		["2023-03-26T01:00:00+00:00", "23:00:00", "-02", 120],
-		["2023-10-29T00:59:59+00:00", "22:59:59", "-02", 120],
-		["2023-10-29T01:00:00+00:00", "22:00:00", "-03", 180]
-	]),
-
-	"2024" : helpers.makeTestYear("America/Godthab", [
-		["2024-03-31T00:59:59+00:00", "21:59:59", "-03", 180],
-		["2024-03-31T01:00:00+00:00", "23:00:00", "-02", 120],
-		["2024-10-27T00:59:59+00:00", "22:59:59", "-02", 120],
-		["2024-10-27T01:00:00+00:00", "22:00:00", "-03", 180]
-	]),
-
-	"2025" : helpers.makeTestYear("America/Godthab", [
-		["2025-03-30T00:59:59+00:00", "21:59:59", "-03", 180],
-		["2025-03-30T01:00:00+00:00", "23:00:00", "-02", 120],
-		["2025-10-26T00:59:59+00:00", "22:59:59", "-02", 120],
-		["2025-10-26T01:00:00+00:00", "22:00:00", "-03", 180]
-	]),
-
-	"2026" : helpers.makeTestYear("America/Godthab", [
-		["2026-03-29T00:59:59+00:00", "21:59:59", "-03", 180],
-		["2026-03-29T01:00:00+00:00", "23:00:00", "-02", 120],
-		["2026-10-25T00:59:59+00:00", "22:59:59", "-02", 120],
-		["2026-10-25T01:00:00+00:00", "22:00:00", "-03", 180]
-	]),
-
-	"2027" : helpers.makeTestYear("America/Godthab", [
-		["2027-03-28T00:59:59+00:00", "21:59:59", "-03", 180],
-		["2027-03-28T01:00:00+00:00", "23:00:00", "-02", 120],
-		["2027-10-31T00:59:59+00:00", "22:59:59", "-02", 120],
-		["2027-10-31T01:00:00+00:00", "22:00:00", "-03", 180]
-	]),
-
-	"2028" : helpers.makeTestYear("America/Godthab", [
-		["2028-03-26T00:59:59+00:00", "21:59:59", "-03", 180],
-		["2028-03-26T01:00:00+00:00", "23:00:00", "-02", 120],
-		["2028-10-29T00:59:59+00:00", "22:59:59", "-02", 120],
-		["2028-10-29T01:00:00+00:00", "22:00:00", "-03", 180]
-	]),
-
-	"2029" : helpers.makeTestYear("America/Godthab", [
-		["2029-03-25T00:59:59+00:00", "21:59:59", "-03", 180],
-		["2029-03-25T01:00:00+00:00", "23:00:00", "-02", 120],
-		["2029-10-28T00:59:59+00:00", "22:59:59", "-02", 120],
-		["2029-10-28T01:00:00+00:00", "22:00:00", "-03", 180]
-	]),
-
-	"2030" : helpers.makeTestYear("America/Godthab", [
-		["2030-03-31T00:59:59+00:00", "21:59:59", "-03", 180],
-		["2030-03-31T01:00:00+00:00", "23:00:00", "-02", 120],
-		["2030-10-27T00:59:59+00:00", "22:59:59", "-02", 120],
-		["2030-10-27T01:00:00+00:00", "22:00:00", "-03", 180]
-	]),
-
-	"2031" : helpers.makeTestYear("America/Godthab", [
-		["2031-03-30T00:59:59+00:00", "21:59:59", "-03", 180],
-		["2031-03-30T01:00:00+00:00", "23:00:00", "-02", 120],
-		["2031-10-26T00:59:59+00:00", "22:59:59", "-02", 120],
-		["2031-10-26T01:00:00+00:00", "22:00:00", "-03", 180]
-	]),
-
-	"2032" : helpers.makeTestYear("America/Godthab", [
-		["2032-03-28T00:59:59+00:00", "21:59:59", "-03", 180],
-		["2032-03-28T01:00:00+00:00", "23:00:00", "-02", 120],
-		["2032-10-31T00:59:59+00:00", "22:59:59", "-02", 120],
-		["2032-10-31T01:00:00+00:00", "22:00:00", "-03", 180]
-	]),
-
-	"2033" : helpers.makeTestYear("America/Godthab", [
-		["2033-03-27T00:59:59+00:00", "21:59:59", "-03", 180],
-		["2033-03-27T01:00:00+00:00", "23:00:00", "-02", 120],
-		["2033-10-30T00:59:59+00:00", "22:59:59", "-02", 120],
-		["2033-10-30T01:00:00+00:00", "22:00:00", "-03", 180]
-	]),
-
-	"2034" : helpers.makeTestYear("America/Godthab", [
-		["2034-03-26T00:59:59+00:00", "21:59:59", "-03", 180],
-		["2034-03-26T01:00:00+00:00", "23:00:00", "-02", 120],
-		["2034-10-29T00:59:59+00:00", "22:59:59", "-02", 120],
-		["2034-10-29T01:00:00+00:00", "22:00:00", "-03", 180]
-	]),
-
-	"2035" : helpers.makeTestYear("America/Godthab", [
-		["2035-03-25T00:59:59+00:00", "21:59:59", "-03", 180],
-		["2035-03-25T01:00:00+00:00", "23:00:00", "-02", 120],
-		["2035-10-28T00:59:59+00:00", "22:59:59", "-02", 120],
-		["2035-10-28T01:00:00+00:00", "22:00:00", "-03", 180]
-	]),
-
-	"2036" : helpers.makeTestYear("America/Godthab", [
-		["2036-03-30T00:59:59+00:00", "21:59:59", "-03", 180],
-		["2036-03-30T01:00:00+00:00", "23:00:00", "-02", 120],
-		["2036-10-26T00:59:59+00:00", "22:59:59", "-02", 120],
-		["2036-10-26T01:00:00+00:00", "22:00:00", "-03", 180]
-	]),
-
-	"2037" : helpers.makeTestYear("America/Godthab", [
-		["2037-03-29T00:59:59+00:00", "21:59:59", "-03", 180],
-		["2037-03-29T01:00:00+00:00", "23:00:00", "-02", 120],
-		["2037-10-25T00:59:59+00:00", "22:59:59", "-02", 120],
-		["2037-10-25T01:00:00+00:00", "22:00:00", "-03", 180]
+		["2023-03-26T00:59:59+00:00", "21:59:59", "-03", 180]
 	])
 };
\ No newline at end of file
