@@ -24,8 +24,8 @@ exports["America/Hermosillo"] = {
 
 	"1931" : helpers.makeTestYear("America/Hermosillo", [
 		["1931-05-02T05:59:59+00:00", "22:59:59", "MST", 420],
-		["1931-05-02T06:00:00+00:00", "00:00:00", "CST", 360],
-		["1931-10-01T05:59:59+00:00", "23:59:59", "CST", 360],
+		["1931-05-02T06:00:00+00:00", "00:00:00", "MDT", 360],
+		["1931-10-01T05:59:59+00:00", "23:59:59", "MDT", 360],
 		["1931-10-01T06:00:00+00:00", "23:00:00", "MST", 420]
 	]),
 
