@@ -9,7 +9,6 @@ exports["America/Mexico_City"] = {
 	"guess:by:abbr" : helpers.makeTestGuess("America/Mexico_City", { abbr: true }),
 
 	"1922" : helpers.makeTestYear("America/Mexico_City", [
-		["1922-01-01T06:59:59+00:00", "00:23:23", "LMT", 23796 / 60],
 		["1922-01-01T07:00:00+00:00", "00:00:00", "MST", 420]
 	]),
 
@@ -25,8 +24,8 @@ exports["America/Mexico_City"] = {
 
 	"1931" : helpers.makeTestYear("America/Mexico_City", [
 		["1931-05-02T05:59:59+00:00", "22:59:59", "MST", 420],
-		["1931-05-02T06:00:00+00:00", "00:00:00", "CST", 360],
-		["1931-10-01T05:59:59+00:00", "23:59:59", "CST", 360],
+		["1931-05-02T06:00:00+00:00", "00:00:00", "MDT", 360],
+		["1931-10-01T05:59:59+00:00", "23:59:59", "MDT", 360],
 		["1931-10-01T06:00:00+00:00", "23:00:00", "MST", 420]
 	]),
 
@@ -254,112 +253,6 @@ exports["America/Mexico_City"] = {
 	"2022" : helpers.makeTestYear("America/Mexico_City", [
 		["2022-04-03T07:59:59+00:00", "01:59:59", "CST", 360],
 		["2022-04-03T08:00:00+00:00", "03:00:00", "CDT", 300],
-		["2022-10-30T06:59:59+00:00", "01:59:59", "CDT", 300],
-		["2022-10-30T07:00:00+00:00", "01:00:00", "CST", 360]
-	]),
-
-	"2023" : helpers.makeTestYear("America/Mexico_City", [
-		["2023-04-02T07:59:59+00:00", "01:59:59", "CST", 360],
-		["2023-04-02T08:00:00+00:00", "03:00:00", "CDT", 300],
-		["2023-10-29T06:59:59+00:00", "01:59:59", "CDT", 300],
-		["2023-10-29T07:00:00+00:00", "01:00:00", "CST", 360]
-	]),
-
-	"2024" : helpers.makeTestYear("America/Mexico_City", [
-		["2024-04-07T07:59:59+00:00", "01:59:59", "CST", 360],
-		["2024-04-07T08:00:00+00:00", "03:00:00", "CDT", 300],
-		["2024-10-27T06:59:59+00:00", "01:59:59", "CDT", 300],
-		["2024-10-27T07:00:00+00:00", "01:00:00", "CST", 360]
-	]),
-
-	"2025" : helpers.makeTestYear("America/Mexico_City", [
-		["2025-04-06T07:59:59+00:00", "01:59:59", "CST", 360],
-		["2025-04-06T08:00:00+00:00", "03:00:00", "CDT", 300],
-		["2025-10-26T06:59:59+00:00", "01:59:59", "CDT", 300],
-		["2025-10-26T07:00:00+00:00", "01:00:00", "CST", 360]
-	]),
-
-	"2026" : helpers.makeTestYear("America/Mexico_City", [
-		["2026-04-05T07:59:59+00:00", "01:59:59", "CST", 360],
-		["2026-04-05T08:00:00+00:00", "03:00:00", "CDT", 300],
-		["2026-10-25T06:59:59+00:00", "01:59:59", "CDT", 300],
-		["2026-10-25T07:00:00+00:00", "01:00:00", "CST", 360]
-	]),
-
-	"2027" : helpers.makeTestYear("America/Mexico_City", [
-		["2027-04-04T07:59:59+00:00", "01:59:59", "CST", 360],
-		["2027-04-04T08:00:00+00:00", "03:00:00", "CDT", 300],
-		["2027-10-31T06:59:59+00:00", "01:59:59", "CDT", 300],
-		["2027-10-31T07:00:00+00:00", "01:00:00", "CST", 360]
-	]),
-
-	"2028" : helpers.makeTestYear("America/Mexico_City", [
-		["2028-04-02T07:59:59+00:00", "01:59:59", "CST", 360],
-		["2028-04-02T08:00:00+00:00", "03:00:00", "CDT", 300],
-		["2028-10-29T06:59:59+00:00", "01:59:59", "CDT", 300],
-		["2028-10-29T07:00:00+00:00", "01:00:00", "CST", 360]
-	]),
-
-	"2029" : helpers.makeTestYear("America/Mexico_City", [
-		["2029-04-01T07:59:59+00:00", "01:59:59", "CST", 360],
-		["2029-04-01T08:00:00+00:00", "03:00:00", "CDT", 300],
-		["2029-10-28T06:59:59+00:00", "01:59:59", "CDT", 300],
-		["2029-10-28T07:00:00+00:00", "01:00:00", "CST", 360]
-	]),
-
-	"2030" : helpers.makeTestYear("America/Mexico_City", [
-		["2030-04-07T07:59:59+00:00", "01:59:59", "CST", 360],
-		["2030-04-07T08:00:00+00:00", "03:00:00", "CDT", 300],
-		["2030-10-27T06:59:59+00:00", "01:59:59", "CDT", 300],
-		["2030-10-27T07:00:00+00:00", "01:00:00", "CST", 360]
-	]),
-
-	"2031" : helpers.makeTestYear("America/Mexico_City", [
-		["2031-04-06T07:59:59+00:00", "01:59:59", "CST", 360],
-		["2031-04-06T08:00:00+00:00", "03:00:00", "CDT", 300],
-		["2031-10-26T06:59:59+00:00", "01:59:59", "CDT", 300],
-		["2031-10-26T07:00:00+00:00", "01:00:00", "CST", 360]
-	]),
-
-	"2032" : helpers.makeTestYear("America/Mexico_City", [
-		["2032-04-04T07:59:59+00:00", "01:59:59", "CST", 360],
-		["2032-04-04T08:00:00+00:00", "03:00:00", "CDT", 300],
-		["2032-10-31T06:59:59+00:00", "01:59:59", "CDT", 300],
-		["2032-10-31T07:00:00+00:00", "01:00:00", "CST", 360]
-	]),
-
-	"2033" : helpers.makeTestYear("America/Mexico_City", [
-		["2033-04-03T07:59:59+00:00", "01:59:59", "CST", 360],
-		["2033-04-03T08:00:00+00:00", "03:00:00", "CDT", 300],
-		["2033-10-30T06:59:59+00:00", "01:59:59", "CDT", 300],
-		["2033-10-30T07:00:00+00:00", "01:00:00", "CST", 360]
-	]),
-
-	"2034" : helpers.makeTestYear("America/Mexico_City", [
-		["2034-04-02T07:59:59+00:00", "01:59:59", "CST", 360],
-		["2034-04-02T08:00:00+00:00", "03:00:00", "CDT", 300],
-		["2034-10-29T06:59:59+00:00", "01:59:59", "CDT", 300],
-		["2034-10-29T07:00:00+00:00", "01:00:00", "CST", 360]
-	]),
-
-	"2035" : helpers.makeTestYear("America/Mexico_City", [
-		["2035-04-01T07:59:59+00:00", "01:59:59", "CST", 360],
-		["2035-04-01T08:00:00+00:00", "03:00:00", "CDT", 300],
-		["2035-10-28T06:59:59+00:00", "01:59:59", "CDT", 300],
-		["2035-10-28T07:00:00+00:00", "01:00:00", "CST", 360]
-	]),
-
-	"2036" : helpers.makeTestYear("America/Mexico_City", [
-		["2036-04-06T07:59:59+00:00", "01:59:59", "CST", 360],
-		["2036-04-06T08:00:00+00:00", "03:00:00", "CDT", 300],
-		["2036-10-26T06:59:59+00:00", "01:59:59", "CDT", 300],
-		["2036-10-26T07:00:00+00:00", "01:00:00", "CST", 360]
-	]),
-
-	"2037" : helpers.makeTestYear("America/Mexico_City", [
-		["2037-04-05T07:59:59+00:00", "01:59:59", "CST", 360],
-		["2037-04-05T08:00:00+00:00", "03:00:00", "CDT", 300],
-		["2037-10-25T06:59:59+00:00", "01:59:59", "CDT", 300],
-		["2037-10-25T07:00:00+00:00", "01:00:00", "CST", 360]
+		["2022-10-30T06:59:59+00:00", "01:59:59", "CDT", 300]
 	])
 };
\ No newline at end of file
