@@ -4,12 +4,11 @@ var helpers = require("../../helpers/helpers");
 
 exports["America/Recife"] = {
 
-	"guess:by:offset" : helpers.makeTestGuess("America/Recife", { offset: true, expect: "America/Fortaleza" }),
+	"guess:by:offset" : helpers.makeTestGuess("America/Recife", { offset: true, expect: "America/Sao_Paulo" }),
 
-	"guess:by:abbr" : helpers.makeTestGuess("America/Recife", { abbr: true, expect: "America/Fortaleza" }),
+	"guess:by:abbr" : helpers.makeTestGuess("America/Recife", { abbr: true, expect: "America/Sao_Paulo" }),
 
 	"1914" : helpers.makeTestYear("America/Recife", [
-		["1914-01-01T02:19:35+00:00", "23:59:59", "LMT", 8376 / 60],
 		["1914-01-01T02:19:36+00:00", "23:19:36", "-03", 180]
 	]),
 
@@ -157,7 +156,6 @@ exports["America/Recife"] = {
 	]),
 
 	"2002" : helpers.makeTestYear("America/Recife", [
-		["2002-02-17T01:59:59+00:00", "23:59:59", "-02", 120],
-		["2002-02-17T02:00:00+00:00", "23:00:00", "-03", 180]
+		["2002-02-17T01:59:59+00:00", "23:59:59", "-02", 120]
 	])
 };
\ No newline at end of file
