@@ -8,6 +8,10 @@ exports["America/Santo_Domingo"] = {
 
 	"guess:by:abbr" : helpers.makeTestGuess("America/Santo_Domingo", { abbr: true }),
 
+	"1890" : helpers.makeTestYear("America/Santo_Domingo", [
+		["1890-01-01T04:39:36+00:00", "23:59:36", "SDMT", 280]
+	]),
+
 	"1933" : helpers.makeTestYear("America/Santo_Domingo", [
 		["1933-04-01T16:39:59+00:00", "11:59:59", "SDMT", 280],
 		["1933-04-01T16:40:00+00:00", "11:40:00", "EST", 300]
@@ -65,6 +69,7 @@ exports["America/Santo_Domingo"] = {
 
 	"2000" : helpers.makeTestYear("America/Santo_Domingo", [
 		["2000-10-29T05:59:59+00:00", "01:59:59", "AST", 240],
-		["2000-10-29T06:00:00+00:00", "01:00:00", "EST", 300]
+		["2000-10-29T06:00:00+00:00", "01:00:00", "EST", 300],
+		["2000-12-03T05:59:59+00:00", "00:59:59", "EST", 300]
 	])
 };
\ No newline at end of file
