@@ -8,6 +8,10 @@ exports["Asia/Aqtau"] = {
 
 	"guess:by:abbr" : helpers.makeTestGuess("Asia/Aqtau", { abbr: true, expect: "Asia/Karachi" }),
 
+	"1924" : helpers.makeTestYear("Asia/Aqtau", [
+		["1924-05-01T20:38:56+00:00", "00:38:56", "+04", -240]
+	]),
+
 	"1930" : helpers.makeTestYear("Asia/Aqtau", [
 		["1930-06-20T19:59:59+00:00", "23:59:59", "+04", -240],
 		["1930-06-20T20:00:00+00:00", "01:00:00", "+05", -300]
@@ -176,6 +180,7 @@ exports["Asia/Aqtau"] = {
 
 	"2004" : helpers.makeTestYear("Asia/Aqtau", [
 		["2004-03-27T21:59:59+00:00", "01:59:59", "+04", -240],
-		["2004-03-27T22:00:00+00:00", "03:00:00", "+05", -300]
+		["2004-03-27T22:00:00+00:00", "03:00:00", "+05", -300],
+		["2004-10-30T21:59:59+00:00", "02:59:59", "+05", -300]
 	])
 };
\ No newline at end of file
