@@ -8,6 +8,15 @@ exports["Asia/Calcutta"] = {
 
 	"guess:by:abbr" : helpers.makeTestGuess("Asia/Calcutta", { abbr: true, expect: "Asia/Kolkata" }),
 
+	"1854" : helpers.makeTestYear("Asia/Calcutta", [
+		["1854-06-27T18:06:32+00:00", "23:59:52", "HMT", -21200 / 60]
+	]),
+
+	"1869" : helpers.makeTestYear("Asia/Calcutta", [
+		["1869-12-31T18:06:39+00:00", "23:59:59", "HMT", -21200 / 60],
+		["1869-12-31T18:06:40+00:00", "23:27:50", "MMT", -19270 / 60]
+	]),
+
 	"1905" : helpers.makeTestYear("Asia/Calcutta", [
 		["1905-12-31T18:38:49+00:00", "23:59:59", "MMT", -19270 / 60],
 		["1905-12-31T18:38:50+00:00", "00:08:50", "IST", -330]
@@ -26,7 +35,6 @@ exports["Asia/Calcutta"] = {
 	]),
 
 	"1945" : helpers.makeTestYear("Asia/Calcutta", [
-		["1945-10-14T17:29:59+00:00", "23:59:59", "+0630", -390],
-		["1945-10-14T17:30:00+00:00", "23:00:00", "IST", -330]
+		["1945-10-14T17:29:59+00:00", "23:59:59", "+0630", -390]
 	])
 };
\ No newline at end of file
