@@ -9,7 +9,6 @@ exports["Asia/Damascus"] = {
 	"guess:by:abbr" : helpers.makeTestGuess("Asia/Damascus", { abbr: true }),
 
 	"1919" : helpers.makeTestYear("Asia/Damascus", [
-		["1919-12-31T21:34:47+00:00", "23:59:59", "LMT", -8712 / 60],
 		["1919-12-31T21:34:48+00:00", "23:34:48", "EET", -120]
 	]),
 
@@ -429,112 +428,6 @@ exports["Asia/Damascus"] = {
 	"2022" : helpers.makeTestYear("Asia/Damascus", [
 		["2022-03-24T21:59:59+00:00", "23:59:59", "EET", -120],
 		["2022-03-24T22:00:00+00:00", "01:00:00", "EEST", -180],
-		["2022-10-27T20:59:59+00:00", "23:59:59", "EEST", -180],
-		["2022-10-27T21:00:00+00:00", "23:00:00", "EET", -120]
-	]),
-
-	"2023" : helpers.makeTestYear("Asia/Damascus", [
-		["2023-03-30T21:59:59+00:00", "23:59:59", "EET", -120],
-		["2023-03-30T22:00:00+00:00", "01:00:00", "EEST", -180],
-		["2023-10-26T20:59:59+00:00", "23:59:59", "EEST", -180],
-		["2023-10-26T21:00:00+00:00", "23:00:00", "EET", -120]
-	]),
-
-	"2024" : helpers.makeTestYear("Asia/Damascus", [
-		["2024-03-28T21:59:59+00:00", "23:59:59", "EET", -120],
-		["2024-03-28T22:00:00+00:00", "01:00:00", "EEST", -180],
-		["2024-10-24T20:59:59+00:00", "23:59:59", "EEST", -180],
-		["2024-10-24T21:00:00+00:00", "23:00:00", "EET", -120]
-	]),
-
-	"2025" : helpers.makeTestYear("Asia/Damascus", [
-		["2025-03-27T21:59:59+00:00", "23:59:59", "EET", -120],
-		["2025-03-27T22:00:00+00:00", "01:00:00", "EEST", -180],
-		["2025-10-30T20:59:59+00:00", "23:59:59", "EEST", -180],
-		["2025-10-30T21:00:00+00:00", "23:00:00", "EET", -120]
-	]),
-
-	"2026" : helpers.makeTestYear("Asia/Damascus", [
-		["2026-03-26T21:59:59+00:00", "23:59:59", "EET", -120],
-		["2026-03-26T22:00:00+00:00", "01:00:00", "EEST", -180],
-		["2026-10-29T20:59:59+00:00", "23:59:59", "EEST", -180],
-		["2026-10-29T21:00:00+00:00", "23:00:00", "EET", -120]
-	]),
-
-	"2027" : helpers.makeTestYear("Asia/Damascus", [
-		["2027-03-25T21:59:59+00:00", "23:59:59", "EET", -120],
-		["2027-03-25T22:00:00+00:00", "01:00:00", "EEST", -180],
-		["2027-10-28T20:59:59+00:00", "23:59:59", "EEST", -180],
-		["2027-10-28T21:00:00+00:00", "23:00:00", "EET", -120]
-	]),
-
-	"2028" : helpers.makeTestYear("Asia/Damascus", [
-		["2028-03-30T21:59:59+00:00", "23:59:59", "EET", -120],
-		["2028-03-30T22:00:00+00:00", "01:00:00", "EEST", -180],
-		["2028-10-26T20:59:59+00:00", "23:59:59", "EEST", -180],
-		["2028-10-26T21:00:00+00:00", "23:00:00", "EET", -120]
-	]),
-
-	"2029" : helpers.makeTestYear("Asia/Damascus", [
-		["2029-03-29T21:59:59+00:00", "23:59:59", "EET", -120],
-		["2029-03-29T22:00:00+00:00", "01:00:00", "EEST", -180],
-		["2029-10-25T20:59:59+00:00", "23:59:59", "EEST", -180],
-		["2029-10-25T21:00:00+00:00", "23:00:00", "EET", -120]
-	]),
-
-	"2030" : helpers.makeTestYear("Asia/Damascus", [
-		["2030-03-28T21:59:59+00:00", "23:59:59", "EET", -120],
-		["2030-03-28T22:00:00+00:00", "01:00:00", "EEST", -180],
-		["2030-10-24T20:59:59+00:00", "23:59:59", "EEST", -180],
-		["2030-10-24T21:00:00+00:00", "23:00:00", "EET", -120]
-	]),
-
-	"2031" : helpers.makeTestYear("Asia/Damascus", [
-		["2031-03-27T21:59:59+00:00", "23:59:59", "EET", -120],
-		["2031-03-27T22:00:00+00:00", "01:00:00", "EEST", -180],
-		["2031-10-30T20:59:59+00:00", "23:59:59", "EEST", -180],
-		["2031-10-30T21:00:00+00:00", "23:00:00", "EET", -120]
-	]),
-
-	"2032" : helpers.makeTestYear("Asia/Damascus", [
-		["2032-03-25T21:59:59+00:00", "23:59:59", "EET", -120],
-		["2032-03-25T22:00:00+00:00", "01:00:00", "EEST", -180],
-		["2032-10-28T20:59:59+00:00", "23:59:59", "EEST", -180],
-		["2032-10-28T21:00:00+00:00", "23:00:00", "EET", -120]
-	]),
-
-	"2033" : helpers.makeTestYear("Asia/Damascus", [
-		["2033-03-24T21:59:59+00:00", "23:59:59", "EET", -120],
-		["2033-03-24T22:00:00+00:00", "01:00:00", "EEST", -180],
-		["2033-10-27T20:59:59+00:00", "23:59:59", "EEST", -180],
-		["2033-10-27T21:00:00+00:00", "23:00:00", "EET", -120]
-	]),
-
-	"2034" : helpers.makeTestYear("Asia/Damascus", [
-		["2034-03-30T21:59:59+00:00", "23:59:59", "EET", -120],
-		["2034-03-30T22:00:00+00:00", "01:00:00", "EEST", -180],
-		["2034-10-26T20:59:59+00:00", "23:59:59", "EEST", -180],
-		["2034-10-26T21:00:00+00:00", "23:00:00", "EET", -120]
-	]),
-
-	"2035" : helpers.makeTestYear("Asia/Damascus", [
-		["2035-03-29T21:59:59+00:00", "23:59:59", "EET", -120],
-		["2035-03-29T22:00:00+00:00", "01:00:00", "EEST", -180],
-		["2035-10-25T20:59:59+00:00", "23:59:59", "EEST", -180],
-		["2035-10-25T21:00:00+00:00", "23:00:00", "EET", -120]
-	]),
-
-	"2036" : helpers.makeTestYear("Asia/Damascus", [
-		["2036-03-27T21:59:59+00:00", "23:59:59", "EET", -120],
-		["2036-03-27T22:00:00+00:00", "01:00:00", "EEST", -180],
-		["2036-10-30T20:59:59+00:00", "23:59:59", "EEST", -180],
-		["2036-10-30T21:00:00+00:00", "23:00:00", "EET", -120]
-	]),
-
-	"2037" : helpers.makeTestYear("Asia/Damascus", [
-		["2037-03-26T21:59:59+00:00", "23:59:59", "EET", -120],
-		["2037-03-26T22:00:00+00:00", "01:00:00", "EEST", -180],
-		["2037-10-29T20:59:59+00:00", "23:59:59", "EEST", -180],
-		["2037-10-29T21:00:00+00:00", "23:00:00", "EET", -120]
+		["2022-10-27T20:59:59+00:00", "23:59:59", "EEST", -180]
 	])
 };
\ No newline at end of file
