@@ -8,6 +8,10 @@ exports["Asia/Dhaka"] = {
 
 	"guess:by:abbr" : helpers.makeTestGuess("Asia/Dhaka", { abbr: true }),
 
+	"1889" : helpers.makeTestYear("Asia/Dhaka", [
+		["1889-12-31T17:58:20+00:00", "23:51:40", "HMT", -21200 / 60]
+	]),
+
 	"1941" : helpers.makeTestYear("Asia/Dhaka", [
 		["1941-09-30T18:06:39+00:00", "23:59:59", "HMT", -21200 / 60],
 		["1941-09-30T18:06:40+00:00", "00:36:40", "+0630", -390]
@@ -28,7 +32,6 @@ exports["Asia/Dhaka"] = {
 	"2009" : helpers.makeTestYear("Asia/Dhaka", [
 		["2009-06-19T16:59:59+00:00", "22:59:59", "+06", -360],
 		["2009-06-19T17:00:00+00:00", "00:00:00", "+07", -420],
-		["2009-12-31T16:59:59+00:00", "23:59:59", "+07", -420],
-		["2009-12-31T17:00:00+00:00", "23:00:00", "+06", -360]
+		["2009-12-31T16:59:59+00:00", "23:59:59", "+07", -420]
 	])
 };
\ No newline at end of file
