@@ -9,7 +9,6 @@ exports["Asia/Dili"] = {
 	"guess:by:abbr" : helpers.makeTestGuess("Asia/Dili", { abbr: true, expect: "Asia/Tokyo" }),
 
 	"1911" : helpers.makeTestYear("Asia/Dili", [
-		["1911-12-31T15:37:39+00:00", "23:59:59", "LMT", -30140 / 60],
 		["1911-12-31T15:37:40+00:00", "23:37:40", "+08", -480]
 	]),
 
@@ -24,7 +23,6 @@ exports["Asia/Dili"] = {
 	]),
 
 	"2000" : helpers.makeTestYear("Asia/Dili", [
-		["2000-09-16T15:59:59+00:00", "23:59:59", "+08", -480],
-		["2000-09-16T16:00:00+00:00", "01:00:00", "+09", -540]
+		["2000-09-16T15:59:59+00:00", "23:59:59", "+08", -480]
 	])
 };
\ No newline at end of file
