@@ -8,6 +8,10 @@ exports["Asia/Dushanbe"] = {
 
 	"guess:by:abbr" : helpers.makeTestGuess("Asia/Dushanbe", { abbr: true, expect: "Asia/Karachi" }),
 
+	"1924" : helpers.makeTestYear("Asia/Dushanbe", [
+		["1924-05-01T19:24:48+00:00", "00:24:48", "+05", -300]
+	]),
+
 	"1930" : helpers.makeTestYear("Asia/Dushanbe", [
 		["1930-06-20T18:59:59+00:00", "23:59:59", "+05", -300],
 		["1930-06-20T19:00:00+00:00", "01:00:00", "+06", -360]
@@ -85,6 +89,7 @@ exports["Asia/Dushanbe"] = {
 
 	"1991" : helpers.makeTestYear("Asia/Dushanbe", [
 		["1991-03-30T19:59:59+00:00", "01:59:59", "+06", -360],
-		["1991-03-30T20:00:00+00:00", "02:00:00", "+06", -360]
+		["1991-03-30T20:00:00+00:00", "02:00:00", "+06", -360],
+		["1991-09-08T20:59:59+00:00", "02:59:59", "+06", -360]
 	])
 };
\ No newline at end of file
