@@ -8,6 +8,10 @@ exports["Asia/Irkutsk"] = {
 
 	"guess:by:abbr" : helpers.makeTestGuess("Asia/Irkutsk", { abbr: true, expect: "Asia/Manila" }),
 
+	"1879" : helpers.makeTestYear("Asia/Irkutsk", [
+		["1879-12-31T17:02:55+00:00", "00:00:00", "IMT", -25025 / 60]
+	]),
+
 	"1920" : helpers.makeTestYear("Asia/Irkutsk", [
 		["1920-01-24T17:02:54+00:00", "23:59:59", "IMT", -25025 / 60],
 		["1920-01-24T17:02:55+00:00", "00:02:55", "+07", -420]
@@ -233,5 +237,9 @@ exports["Asia/Irkutsk"] = {
 	"2011" : helpers.makeTestYear("Asia/Irkutsk", [
 		["2011-03-26T17:59:59+00:00", "01:59:59", "+08", -480],
 		["2011-03-26T18:00:00+00:00", "03:00:00", "+09", -540]
+	]),
+
+	"2014" : helpers.makeTestYear("Asia/Irkutsk", [
+		["2014-10-25T16:59:59+00:00", "01:59:59", "+09", -540]
 	])
 };
\ No newline at end of file
