@@ -8,6 +8,10 @@ exports["Asia/Jakarta"] = {
 
 	"guess:by:abbr" : helpers.makeTestGuess("Asia/Jakarta", { abbr: true }),
 
+	"1867" : helpers.makeTestYear("Asia/Jakarta", [
+		["1867-08-09T16:52:48+00:00", "00:00:00", "BMT", -25632 / 60]
+	]),
+
 	"1923" : helpers.makeTestYear("Asia/Jakarta", [
 		["1923-12-31T16:39:59+00:00", "23:47:11", "BMT", -25632 / 60],
 		["1923-12-31T16:40:00+00:00", "00:00:00", "+0720", -440]
@@ -39,7 +43,6 @@ exports["Asia/Jakarta"] = {
 	]),
 
 	"1963" : helpers.makeTestYear("Asia/Jakarta", [
-		["1963-12-31T16:29:59+00:00", "23:59:59", "+0730", -450],
-		["1963-12-31T16:30:00+00:00", "23:30:00", "WIB", -420]
+		["1963-12-31T16:29:59+00:00", "23:59:59", "+0730", -450]
 	])
 };
\ No newline at end of file
