@@ -9,7 +9,6 @@ exports["Asia/Jayapura"] = {
 	"guess:by:abbr" : helpers.makeTestGuess("Asia/Jayapura", { abbr: true }),
 
 	"1932" : helpers.makeTestYear("Asia/Jayapura", [
-		["1932-10-31T14:37:11+00:00", "23:59:59", "LMT", -33768 / 60],
 		["1932-10-31T14:37:12+00:00", "23:37:12", "+09", -540]
 	]),
 
@@ -19,7 +18,6 @@ exports["Asia/Jayapura"] = {
 	]),
 
 	"1963" : helpers.makeTestYear("Asia/Jayapura", [
-		["1963-12-31T14:29:59+00:00", "23:59:59", "+0930", -570],
-		["1963-12-31T14:30:00+00:00", "23:30:00", "WIT", -540]
+		["1963-12-31T14:29:59+00:00", "23:59:59", "+0930", -570]
 	])
 };
\ No newline at end of file
