@@ -9,7 +9,6 @@ exports["Asia/Khandyga"] = {
 	"guess:by:abbr" : helpers.makeTestGuess("Asia/Khandyga", { abbr: true, expect: "Asia/Tokyo" }),
 
 	"1919" : helpers.makeTestYear("Asia/Khandyga", [
-		["1919-12-14T14:57:46+00:00", "23:59:59", "LMT", -32533 / 60],
 		["1919-12-14T14:57:47+00:00", "22:57:47", "+08", -480]
 	]),
 
@@ -240,7 +239,6 @@ exports["Asia/Khandyga"] = {
 	]),
 
 	"2014" : helpers.makeTestYear("Asia/Khandyga", [
-		["2014-10-25T15:59:59+00:00", "01:59:59", "+10", -600],
-		["2014-10-25T16:00:00+00:00", "01:00:00", "+09", -540]
+		["2014-10-25T15:59:59+00:00", "01:59:59", "+10", -600]
 	])
 };
\ No newline at end of file
