@@ -9,7 +9,6 @@ exports["Asia/Kuching"] = {
 	"guess:by:abbr" : helpers.makeTestGuess("Asia/Kuching", { abbr: true, expect: "Asia/Manila" }),
 
 	"1926" : helpers.makeTestYear("Asia/Kuching", [
-		["1926-02-28T16:38:39+00:00", "23:59:59", "LMT", -26480 / 60],
 		["1926-02-28T16:38:40+00:00", "00:08:40", "+0730", -450]
 	]),
 
@@ -73,7 +72,6 @@ exports["Asia/Kuching"] = {
 	]),
 
 	"1945" : helpers.makeTestYear("Asia/Kuching", [
-		["1945-09-11T14:59:59+00:00", "23:59:59", "+09", -540],
-		["1945-09-11T15:00:00+00:00", "23:00:00", "+08", -480]
+		["1945-09-11T14:59:59+00:00", "23:59:59", "+09", -540]
 	])
 };
\ No newline at end of file
