@@ -9,7 +9,6 @@ exports["Asia/Macau"] = {
 	"guess:by:abbr" : helpers.makeTestGuess("Asia/Macau", { abbr: true, expect: "Asia/Shanghai" }),
 
 	"1904" : helpers.makeTestYear("Asia/Macau", [
-		["1904-10-29T16:25:49+00:00", "23:59:59", "LMT", -27250 / 60],
 		["1904-10-29T16:25:50+00:00", "00:25:50", "CST", -480]
 	]),
 
@@ -257,7 +256,6 @@ exports["Asia/Macau"] = {
 	"1979" : helpers.makeTestYear("Asia/Macau", [
 		["1979-05-12T19:29:59+00:00", "03:29:59", "CST", -480],
 		["1979-05-12T19:30:00+00:00", "04:30:00", "CDT", -540],
-		["1979-10-20T18:29:59+00:00", "03:29:59", "CDT", -540],
-		["1979-10-20T18:30:00+00:00", "02:30:00", "CST", -480]
+		["1979-10-20T18:29:59+00:00", "03:29:59", "CDT", -540]
 	])
 };
\ No newline at end of file
