@@ -9,7 +9,6 @@ exports["Asia/Qostanay"] = {
 	"guess:by:abbr" : helpers.makeTestGuess("Asia/Qostanay", { abbr: true, expect: "Asia/Dhaka" }),
 
 	"1924" : helpers.makeTestYear("Asia/Qostanay", [
-		["1924-05-01T19:45:31+00:00", "23:59:59", "LMT", -15268 / 60],
 		["1924-05-01T19:45:32+00:00", "23:45:32", "+04", -240]
 	]),
 
@@ -184,7 +183,6 @@ exports["Asia/Qostanay"] = {
 	"2004" : helpers.makeTestYear("Asia/Qostanay", [
 		["2004-03-27T20:59:59+00:00", "01:59:59", "+05", -300],
 		["2004-03-27T21:00:00+00:00", "03:00:00", "+06", -360],
-		["2004-10-30T20:59:59+00:00", "02:59:59", "+06", -360],
-		["2004-10-30T21:00:00+00:00", "03:00:00", "+06", -360]
+		["2004-10-30T20:59:59+00:00", "02:59:59", "+06", -360]
 	])
 };
\ No newline at end of file
