@@ -9,7 +9,6 @@ exports["Asia/Ujung_Pandang"] = {
 	"guess:by:abbr" : helpers.makeTestGuess("Asia/Ujung_Pandang", { abbr: true, expect: "Asia/Makassar" }),
 
 	"1919" : helpers.makeTestYear("Asia/Ujung_Pandang", [
-		["1919-12-31T16:02:23+00:00", "23:59:59", "LMT", -28656 / 60],
 		["1919-12-31T16:02:24+00:00", "00:00:00", "MMT", -28656 / 60]
 	]),
 
@@ -24,7 +23,6 @@ exports["Asia/Ujung_Pandang"] = {
 	]),
 
 	"1945" : helpers.makeTestYear("Asia/Ujung_Pandang", [
-		["1945-09-22T14:59:59+00:00", "23:59:59", "+09", -540],
-		["1945-09-22T15:00:00+00:00", "23:00:00", "WITA", -480]
+		["1945-09-22T14:59:59+00:00", "23:59:59", "+09", -540]
 	])
 };
\ No newline at end of file
