@@ -9,7 +9,6 @@ exports["Asia/Vladivostok"] = {
 	"guess:by:abbr" : helpers.makeTestGuess("Asia/Vladivostok", { abbr: true, expect: "Australia/Brisbane" }),
 
 	"1922" : helpers.makeTestYear("Asia/Vladivostok", [
-		["1922-11-14T15:12:28+00:00", "23:59:59", "LMT", -31651 / 60],
 		["1922-11-14T15:12:29+00:00", "00:12:29", "+09", -540]
 	]),
 
@@ -236,7 +235,6 @@ exports["Asia/Vladivostok"] = {
 	]),
 
 	"2014" : helpers.makeTestYear("Asia/Vladivostok", [
-		["2014-10-25T14:59:59+00:00", "01:59:59", "+11", -660],
-		["2014-10-25T15:00:00+00:00", "01:00:00", "+10", -600]
+		["2014-10-25T14:59:59+00:00", "01:59:59", "+11", -660]
 	])
 };
\ No newline at end of file
