@@ -6,7 +6,7 @@ exports["Etc/UCT"] = {
 
 	"guess:by:offset" : helpers.makeTestGuess("Etc/UCT", { offset: true, expect: "Africa/Abidjan" }),
 
-	"guess:by:abbr" : helpers.makeTestGuess("Etc/UCT", { abbr: true }),
+	"guess:by:abbr" : helpers.makeTestGuess("Etc/UCT", { abbr: true, expect: "Etc/UTC" }),
 
 
 };
\ No newline at end of file
