@@ -8,6 +8,10 @@ exports["Europe/Istanbul"] = {
 
 	"guess:by:abbr" : helpers.makeTestGuess("Europe/Istanbul", { abbr: true, expect: "Europe/Moscow" }),
 
+	"1879" : helpers.makeTestYear("Europe/Istanbul", [
+		["1879-12-31T22:04:08+00:00", "00:01:04", "IMT", -7016 / 60]
+	]),
+
 	"1910" : helpers.makeTestYear("Europe/Istanbul", [
 		["1910-09-30T22:03:03+00:00", "23:59:59", "IMT", -7016 / 60],
 		["1910-09-30T22:03:04+00:00", "00:03:04", "EET", -120]
@@ -412,7 +416,6 @@ exports["Europe/Istanbul"] = {
 	"2016" : helpers.makeTestYear("Europe/Istanbul", [
 		["2016-03-27T00:59:59+00:00", "02:59:59", "EET", -120],
 		["2016-03-27T01:00:00+00:00", "04:00:00", "EEST", -180],
-		["2016-09-06T20:59:59+00:00", "23:59:59", "EEST", -180],
-		["2016-09-06T21:00:00+00:00", "00:00:00", "+03", -180]
+		["2016-09-06T20:59:59+00:00", "23:59:59", "EEST", -180]
 	])
 };
\ No newline at end of file
