@@ -8,6 +8,10 @@ exports["Europe/Kaliningrad"] = {
 
 	"guess:by:abbr" : helpers.makeTestGuess("Europe/Kaliningrad", { abbr: true, expect: "Africa/Cairo" }),
 
+	"1893" : helpers.makeTestYear("Europe/Kaliningrad", [
+		["1893-03-31T22:38:00+00:00", "23:38:00", "CET", -60]
+	]),
+
 	"1916" : helpers.makeTestYear("Europe/Kaliningrad", [
 		["1916-04-30T21:59:59+00:00", "22:59:59", "CET", -60],
 		["1916-04-30T22:00:00+00:00", "00:00:00", "CEST", -120],
@@ -285,7 +289,6 @@ exports["Europe/Kaliningrad"] = {
 	]),
 
 	"2014" : helpers.makeTestYear("Europe/Kaliningrad", [
-		["2014-10-25T22:59:59+00:00", "01:59:59", "+03", -180],
-		["2014-10-25T23:00:00+00:00", "01:00:00", "EET", -120]
+		["2014-10-25T22:59:59+00:00", "01:59:59", "+03", -180]
 	])
 };
\ No newline at end of file
