@@ -8,11 +8,11 @@ exports["Indian/Kerguelen"] = {
 
 	"guess:by:abbr" : helpers.makeTestGuess("Indian/Kerguelen", { abbr: true, expect: "Asia/Karachi" }),
 
-	"1949" : helpers.makeTestYear("Indian/Kerguelen", [
-		["1949-12-31T23:59:59+00:00", "23:59:59", "-00", 0]
+	"1879" : helpers.makeTestYear("Indian/Kerguelen", [
+		["1879-12-31T19:06:00+00:00", "00:00:00", "MMT", -294]
 	]),
 
-	"1950" : helpers.makeTestYear("Indian/Kerguelen", [
-		["1950-01-01T00:00:00+00:00", "05:00:00", "+05", -300]
+	"1959" : helpers.makeTestYear("Indian/Kerguelen", [
+		["1959-12-31T19:05:59+00:00", "23:59:59", "MMT", -294]
 	])
 };
\ No newline at end of file
