@@ -8,6 +8,10 @@ exports["Japan"] = {
 
 	"guess:by:abbr" : helpers.makeTestGuess("Japan", { abbr: true, expect: "Asia/Tokyo" }),
 
+	"1887" : helpers.makeTestYear("Japan", [
+		["1887-12-31T15:00:00+00:00", "00:00:00", "JST", -540]
+	]),
+
 	"1948" : helpers.makeTestYear("Japan", [
 		["1948-05-01T14:59:59+00:00", "23:59:59", "JST", -540],
 		["1948-05-01T15:00:00+00:00", "01:00:00", "JDT", -600],
@@ -32,7 +36,6 @@ exports["Japan"] = {
 	"1951" : helpers.makeTestYear("Japan", [
 		["1951-05-05T14:59:59+00:00", "23:59:59", "JST", -540],
 		["1951-05-05T15:00:00+00:00", "01:00:00", "JDT", -600],
-		["1951-09-08T14:59:59+00:00", "00:59:59", "JDT", -600],
-		["1951-09-08T15:00:00+00:00", "00:00:00", "JST", -540]
+		["1951-09-08T14:59:59+00:00", "00:59:59", "JDT", -600]
 	])
 };
\ No newline at end of file
