@@ -8,6 +8,15 @@ exports["Pacific/Guam"] = {
 
 	"guess:by:abbr" : helpers.makeTestGuess("Pacific/Guam", { abbr: true }),
 
+	"1844" : helpers.makeTestYear("Pacific/Guam", [
+		["1844-12-31T14:21:00+00:00", "00:00:00", "LMT", -579]
+	]),
+
+	"1900" : helpers.makeTestYear("Pacific/Guam", [
+		["1900-12-31T14:20:59+00:00", "23:59:59", "LMT", -579],
+		["1900-12-31T14:21:00+00:00", "00:21:00", "GST", -600]
+	]),
+
 	"1941" : helpers.makeTestYear("Pacific/Guam", [
 		["1941-12-09T13:59:59+00:00", "23:59:59", "GST", -600],
 		["1941-12-09T14:00:00+00:00", "23:00:00", "+09", -540]
@@ -81,7 +90,6 @@ exports["Pacific/Guam"] = {
 	]),
 
 	"2000" : helpers.makeTestYear("Pacific/Guam", [
-		["2000-12-22T13:59:59+00:00", "23:59:59", "GST", -600],
-		["2000-12-22T14:00:00+00:00", "00:00:00", "ChST", -600]
+		["2000-12-22T13:59:59+00:00", "23:59:59", "GST", -600]
 	])
 };
\ No newline at end of file
