@@ -9,7 +9,6 @@ exports["Pacific/Nauru"] = {
 	"guess:by:abbr" : helpers.makeTestGuess("Pacific/Nauru", { abbr: true, expect: "Asia/Kamchatka" }),
 
 	"1921" : helpers.makeTestYear("Pacific/Nauru", [
-		["1921-01-14T12:52:19+00:00", "23:59:59", "LMT", -40060 / 60],
 		["1921-01-14T12:52:20+00:00", "00:22:20", "+1130", -690]
 	]),
 
@@ -24,7 +23,6 @@ exports["Pacific/Nauru"] = {
 	]),
 
 	"1979" : helpers.makeTestYear("Pacific/Nauru", [
-		["1979-02-09T14:29:59+00:00", "01:59:59", "+1130", -690],
-		["1979-02-09T14:30:00+00:00", "02:30:00", "+12", -720]
+		["1979-02-09T14:29:59+00:00", "01:59:59", "+1130", -690]
 	])
 };
\ No newline at end of file
