@@ -9,7 +9,6 @@ exports["Pacific/Noumea"] = {
 	"guess:by:abbr" : helpers.makeTestGuess("Pacific/Noumea", { abbr: true, expect: "Asia/Sakhalin" }),
 
 	"1912" : helpers.makeTestYear("Pacific/Noumea", [
-		["1912-01-12T12:54:11+00:00", "23:59:59", "LMT", -39948 / 60],
 		["1912-01-12T12:54:12+00:00", "23:54:12", "+11", -660]
 	]),
 
@@ -36,7 +35,6 @@ exports["Pacific/Noumea"] = {
 	]),
 
 	"1997" : helpers.makeTestYear("Pacific/Noumea", [
-		["1997-03-01T14:59:59+00:00", "02:59:59", "+12", -720],
-		["1997-03-01T15:00:00+00:00", "02:00:00", "+11", -660]
+		["1997-03-01T14:59:59+00:00", "02:59:59", "+12", -720]
 	])
 };
\ No newline at end of file
