@@ -8,6 +8,10 @@ exports["PRC"] = {
 
 	"guess:by:abbr" : helpers.makeTestGuess("PRC", { abbr: true, expect: "Asia/Shanghai" }),
 
+	"1900" : helpers.makeTestYear("PRC", [
+		["1900-12-31T15:54:17+00:00", "23:54:17", "CST", -480]
+	]),
+
 	"1919" : helpers.makeTestYear("PRC", [
 		["1919-04-12T15:59:59+00:00", "23:59:59", "CST", -480],
 		["1919-04-12T16:00:00+00:00", "01:00:00", "CDT", -540],
@@ -105,7 +109,6 @@ exports["PRC"] = {
 	"1991" : helpers.makeTestYear("PRC", [
 		["1991-04-13T17:59:59+00:00", "01:59:59", "CST", -480],
 		["1991-04-13T18:00:00+00:00", "03:00:00", "CDT", -540],
-		["1991-09-14T16:59:59+00:00", "01:59:59", "CDT", -540],
-		["1991-09-14T17:00:00+00:00", "01:00:00", "CST", -480]
+		["1991-09-14T16:59:59+00:00", "01:59:59", "CDT", -540]
 	])
 };
\ No newline at end of file
